Cookie class

Cookie model for internal use. Nothing to do with dependant projects

Annotations

Constructors

Cookie({required String name, required String value, required DateTime expires})
const

Properties

expires DateTime
final
hashCode int
In our case name is only property we distinguish different cookies
no setteroverride
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override